@@ -3,7 +3,7 @@ use uuid::Uuid;
 
 use std::fmt::Display;
 
-use crate::prelude::{Form, Section, Track};
+use crate::prelude::{Form, Section, Track, SectionKind};
 use notation_core::prelude::{
     Key, Note, Pitch, Scale, Signature, Syllable, SyllableNote, Tempo, Units,
 };
@@ -77,6 +77,9 @@ impl Display for Tab {
     }
 }
 impl Tab {
+    pub fn new_uuid() -> String {
+        Uuid::new_v4().to_string()
+    }
     pub fn new(
         uuid: &str,
         meta: TabMeta,
@@ -93,4 +96,18 @@ impl Tab {
             form,
         }
     }
+    pub fn new_empty() -> Self {
+        Self::new(
+            Self::new_uuid().as_str(),
+            TabMeta::default(),
+            vec![],
+            vec![],
+            Form { sections: vec![] },
+        )
+    }
+    pub fn need_rest(&self) -> bool {
+        self.sections.get(0).map(|section|
+            section.kind != SectionKind::Rest
+        ).unwrap_or(false)
+    }
 }
